@@ -62,8 +62,25 @@ def _print_starting_cell(cell, cell_index):
     print(f"Starting cell {cell_index}, {cell}.", flush=True)
 
 
+def _print_cell_output(cell, cell_index, execute_reply):
+    txt = f"Executed cell {cell_index}"
+
+    if "source" in cell:
+        txt += f", source: {cell['source']}."
+    else:
+        txt += "."
+
+    if "outputs" in cell:
+        txt += f" Outputs: {cell['outputs']}."
+
+    print(txt, flush=True)
+
+
 def execute_notebooks(
-    nb_file_folder: Path, write: bool = True, print_cells: bool = False
+    nb_file_folder: Path,
+    write: bool = True,
+    print_cells: bool = False,
+    print_outputs: bool = False,
 ):
     """Execute all notebooks in the folder.
 
@@ -77,6 +94,7 @@ def execute_notebooks(
         write: If `True`, writes the execution results to the notebooks.
         print_cells: If `True`, prints cell indices and content
         on the start of the execution.
+        print_outputs: If `True`, prints cell output for executed cells.
     """
     print(f"Executing notebooks in {nb_file_folder}", flush=True)
 
@@ -139,6 +157,9 @@ def execute_notebooks(
 
         if print_cells:
             client.on_cell_start = _print_starting_cell
+        if print_outputs:
+            client.on_cell_executed = _print_cell_output
+
         print(f"{nb.stem}", end=" ", flush=True)
 
         env["NBPRJ_TEST_NBPATH"] = str(nb)
